#!/usr/bin/python3

import os
import subprocess

import gi
gi.require_version('Nautilus', '3.0')
from gi.repository import Nautilus, GObject


CFGPATH = os.path.expanduser("~/.plmgmt/playlistdir")
CUSTOMENV = None


def notify(title, text):
    subprocess.call([
        'notify-send',
        '-a', 'nautilus',
        title, text,
    ], env=CUSTOMENV)


def run_add_song_to_month_playlist(files):
        cmd = ["add-song-to-month-playlist"]

        try:
            with open(CFGPATH) as f:
                pldir = f.read().strip()
        except Exception:
            notify(
                'Failed to add to playlist'
                'Failed to read configuration file %s' % (CFGPATH,)
            )
        cmd.append(pldir)
        for file_obj in files:
            if file_obj.is_gone():
                continue
            cmd.append(
              os.path.abspath(
                file_obj.get_location().get_path(),
              )
            )
        ret = subprocess.call(cmd, env=CUSTOMENV)
        if ret != 0:
            notify(
                'Failed to add to playlist',
                'Program %s failed with error code %s' % (cmd[0], ret)
            )


class AddSongToMonthPlaylistItemExtension(GObject.GObject, Nautilus.MenuProvider):
    '''Add the selected songs to the month's playlist.'''

    def get_file_items(self, window, files):
        '''Attaches context menu in Nautilus to the appropriate files.'''
        if not files:
            return

        for file_obj in files:

            # Do not attach context menu to a directory
            if file_obj.is_directory():
                return

            # Do not attach context menu  to anything other that a file
            # local files only; not remote
            if file_obj.get_uri_scheme() != 'file':
                return

            # Only attach context menu to pdf files
            mime = file_obj.get_mime_type()
            if not mime.startswith("video") and not mime.startswith("audio"):
                return

        menu_item = Nautilus.MenuItem(name='AddSongToMonthPlaylistMenuProvider::AddSongToMonthPlaylist',
                                      label="Add to month's playlist",
                                      tip="Adds the selected items to this month's playlist",
                                      icon='')

        menu_item.connect('activate', self.on_menu_item_clicked, files)
        return menu_item,

    def on_menu_item_clicked(self, menu, files):
        '''Called when user chooses files though Nautilus context menu.
        '''
        return run_add_song_to_month_playlist(files)
